==> haskell-x509-store-1.6.6-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.6
id: x509-store-1.6.6-Bbi4sh5Pr7lJ9NNpjVYUOW
key: x509-store-1.6.6-Bbi4sh5Pr7lJ9NNpjVYUOW
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: 6d803de557feff37e7f7d596d35dff34
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.4.3/site-local/x509-store-1.6.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/x509-store-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/x509-store-1.6.6
hs-libraries: HSx509-store-1.6.6-Bbi4sh5Pr7lJ9NNpjVYUOW
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 pem-0.2.4-BcLxee31LwCG4REncAHYKL
    asn1-types-0.3.2-JtmyLcWjlAM5Ek6K2mGfDx
    asn1-encoding-0.9.5-DDyi2ItguO01dpepVrV8LU
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    x509-1.7.3-640yHEahM3WBoMfXdzCIrN
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             pem-0.2.4-BcLxee31LwCG4REncAHYKL=1a01360fc022fe0a69bfc1b290c7021b
             asn1-types-0.3.2-JtmyLcWjlAM5Ek6K2mGfDx=bebffe716cd0d972f4600c0542e59d35
             asn1-encoding-0.9.5-DDyi2ItguO01dpepVrV8LU=6dac9042b707027721edcf7f2cdc15df
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             x509-1.7.3-640yHEahM3WBoMfXdzCIrN=e33d4a2ad8a25b93faa3f24698fe2489
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.6-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.6
id: x509-store-1.6.6-GCpkO0OWz3eDSw037PsJgf
key: x509-store-1.6.6-GCpkO0OWz3eDSw037PsJgf
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
abi: bea18e55116d785dcc8f9a2daa0d57a2
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
import-dirs: /usr/lib/ghc-8.4.3/site-local/x509-store-1.6.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/x509-store-1.6.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/x509-store-1.6.6
hs-libraries: HSx509-store-1.6.6-GCpkO0OWz3eDSw037PsJgf
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 pem-0.2.4-BcLxee31LwCG4REncAHYKL
    asn1-types-0.3.2-3RwAdHw1cBjFrGsSnhhLWY
    asn1-encoding-0.9.5-2sNG6Jbqz8FIHqFopEwd9s
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    x509-1.7.3-FA9hMAsTX042gVtUgvaCu4
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             pem-0.2.4-BcLxee31LwCG4REncAHYKL=1a01360fc022fe0a69bfc1b290c7021b
             asn1-types-0.3.2-3RwAdHw1cBjFrGsSnhhLWY=763daf51ab10462f441f8d6e4d30d663
             asn1-encoding-0.9.5-2sNG6Jbqz8FIHqFopEwd9s=3722e0fbe652d5043f982ba533c2098b
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             x509-1.7.3-FA9hMAsTX042gVtUgvaCu4=004a5a65649fda7666571de637986c08
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
